AggregationMethod enum
Aggregation methods for downsampling time-series data.
Values
- average → const AggregationMethod
-
Mean of values in the window.
- minimum → const AggregationMethod
-
Smallest value in the window.
- maximum → const AggregationMethod
-
Largest value in the window.
- sum → const AggregationMethod
-
Sum of values in the window.
- count → const AggregationMethod
-
Number of values in the window.
- first → const AggregationMethod
-
First value in the window.
- last → const AggregationMethod
-
Last value in the window.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AggregationMethod> - A constant List of the values in this enum, in order of their declaration.