AsyncFieldRule class

Async validation rule that performs asynchronous checks.

Constructors

AsyncFieldRule({required Future<String?> asyncValidator(dynamic value), String? message})
const
AsyncFieldRule.async(Future<String?> validator(dynamic value), {String? message})
Creates an async validation rule.
factory

Properties

asyncValidator Future<String?> Function(dynamic value)
Async validation function.
final
hashCode int
The hash code for this object.
no setterinherited
message String?
Custom error message override.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validateAsync(dynamic value) Future<String?>
Validates a value asynchronously against this rule.

Operators

operator ==(Object other) bool
The equality operator.
inherited