AsyncValidationError class

Enhanced validation error for async rules.

Constructors

AsyncValidationError({required String field, required String message, required AsyncFieldRule rule})
Creates an AsyncValidationError.
const

Properties

field String
The field name that failed validation.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
final
rule AsyncFieldRule
The rule that failed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited