AuditAction enum

Audit action types.

Inheritance
Available extensions

Values

create → const AuditAction

A new key-value pair was created.

read → const AuditAction

A value was read.

update → const AuditAction

An existing key-value pair was updated.

delete → const AuditAction

A key-value pair was deleted.

clear → const AuditAction

The box was cleared.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AuditAction>
A constant List of the values in this enum, in order of their declaration.