BinaryReaderImpl class

Not part of public API

Inheritance

Constructors

BinaryReaderImpl(Uint8List _buffer, TypeRegistry typeRegistry, [int? bufferLength])
Not part of public API

Properties

availableBytes int
The number of bytes left in this entry.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usedBytes int
The number of read bytes.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peekBytes(int bytes) Uint8List
Get a Uint8List view which contains the next bytes bytes. This does not advance the internal read position.
override
peekUint32() int
Not part of public API
read([int? typeId]) → dynamic
Read and decode any value.
override
readBool() bool
Read a boolean.
override
readBoolList([int? length]) List<bool>
Read a list of booleans with length.
override
readByte() int
Read a single byte.
override
readByteList([int? length]) Uint8List
Read a list of bytes with length.
override
readBytes(int length) Uint8List
Read length bytes from the buffer
readDouble() double
Read eight bytes as 64-bit double.
override
readDoubleList([int? length]) List<double>
Read a list of doubles with length.
override
readEncrypted(RiftCipher cipher) → dynamic
Not part of public API
readFrame({RiftCipher? cipher, int? keyCrc, bool lazy = false, int frameOffset = 0, bool verbatim = false}) → Frame?
Not part of public API
readInt() int
Read eight bytes as 64-bit signed integer.
override
readInt32() int
Read four bytes as 32-bit signed integer.
override
readIntList([int? length]) List<int>
Read a list of integers with length.
override
readKey() → dynamic
Not part of public API
readList([int? length]) List
Read a list with length.
override
readMap([int? length]) Map
Read a map with length entries.
override
readRiftList([int? length]) RiftList<RiftObjectMixin>
Read a RiftList with length.
override
readString([int? byteCount, Converter<List<int>, String> decoder = BinaryReader.utf8Decoder]) String
Read byteCount bytes and decode an UTF-8 String.
override
readStringList([int? length, Converter<List<int>, String> decoder = BinaryReader.utf8Decoder]) List<String>
Read a list of Strings with length.
override
readTypeId() int
Read a type ID and handle extension
readUint32() int
Read four bytes as 32-bit unsigned integer.
override
readWord() int
Read two bytes as 16-bit unsigned integer.
override
skip(int bytes) → void
Skip n bytes.
override
toString() String
A string representation of this object.
inherited
viewBytes(int bytes) Uint8List
Get a Uint8List view which contains the next bytes bytes.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited