BoxMigrationResult class
Result of migrating a single box from Hive to Rift.
Constructors
- BoxMigrationResult({required String boxName, required bool success, required int entriesMigrated, String? error})
- Create a BoxMigrationResult.
Properties
- boxName → String
-
The name of the box that was migrated.
final
- entriesMigrated → int
-
The number of entries that were migrated.
final
- error → String?
-
Error message if the migration failed, null otherwise.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether the migration succeeded.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited