BoxSnapshot class

A snapshot of a box's state at a specific version.

Constructors

BoxSnapshot({required int version, required DateTime timestamp, required Map<String, dynamic> data})
Create a box snapshot.

Properties

data Map<String, dynamic>
The data in the box at the time of the snapshot.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
When this snapshot was created.
final
version int
The version at which this snapshot was taken.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBox(Box box, int version) Future<BoxSnapshot>
Create a snapshot from a Box at a given version.