CrossFieldRule class

Cross-field validation rule that validates based on multiple fields.

Constructors

CrossFieldRule({required List<String> fields, required String? validator(Map<String, dynamic> values), String? message})
const

Properties

fields List<String>
The fields involved in this validation.
final
hashCode int
The hash code for this object.
no setterinherited
message String?
Custom error message override.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator String? Function(Map<String, dynamic> values)
Validation function that receives all field values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(Map<String, dynamic> data) String?
Validates data against this cross-field rule.

Operators

operator ==(Object other) bool
The equality operator.
inherited