FieldEncryptionConfig class
Configuration for encrypting a specific field.
Constructors
- FieldEncryptionConfig({required String key, EncryptionAlgorithm algorithm = EncryptionAlgorithm.aes256, bool encryptNulls = false})
- Create a field encryption config.
Properties
- algorithm → EncryptionAlgorithm
-
The encryption algorithm to use.
final
- encryptNulls → bool
-
Whether to encrypt null values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
The encryption key.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited