InMemorySyncBackend class

In-memory sync backend for testing. Stores all changes in memory and allows pulling them back.

Implemented types

Constructors

InMemorySyncBackend()

Properties

allChanges List<SyncChange>
Get all stored changes (for testing).
no setter
events Stream<SyncEvent>
Stream of sync events (real-time updates).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status SyncStatus
Current connection status.
no setteroverride

Methods

clearChanges() → void
Clear all stored changes (for testing).
connect(SyncConfig config) Future<void>
Connect to the sync backend with the given config.
override
disconnect() Future<void>
Disconnect from the sync backend.
override
dispose() → void
Dispose the backend.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pullChanges(SyncCursor cursor) Future<List<SyncChange>>
Pull remote changes from the backend since the given cursor.
override
pushChanges(List<SyncChange> changes) Future<SyncResult>
Push local changes to the backend.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited