IndexOperator enum

Operators for index queries.

Inheritance
Available extensions

Values

eq → const IndexOperator

Equal to value.

gt → const IndexOperator

Greater than value.

gte → const IndexOperator

Greater than or equal to value.

lt → const IndexOperator

Less than value.

lte → const IndexOperator

Less than or equal to value.

range → const IndexOperator

Range between two values (inclusive on both ends).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IndexOperator>
A constant List of the values in this enum, in order of their declaration.