LazyStrategy enum

Strategies for lazy loading data.

Inheritance
Available extensions

Values

eager → const LazyStrategy

Load all data immediately when the loader is created.

lazy → const LazyStrategy

Load data on first access (default lazy loading).

onDemand → const LazyStrategy

Load data only when explicitly requested.

scheduled → const LazyStrategy

Load data on a scheduled basis (background refresh).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LazyStrategy>
A constant List of the values in this enum, in order of their declaration.