ObservableMap<K, V> class
A reactive map that notifies listeners on any modification.
ObservableMap implements MapMixin so it can be used as a regular Dart map. Any mutation triggers change notifications.
Usage:
final data = ObservableMap<String, int>();
data.onChange.listen((change) => print('Change: ${change.type} at ${change.key}'));
data['count'] = 1; // Notifies listeners
Constructors
-
ObservableMap([Map<
K, V> ? entries]) -
Creates an ObservableMap with optional initial
entries.
Properties
-
entries
→ Iterable<
MapEntry< K, V> > -
The map entries of this Map.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setterinherited
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setterinherited
-
keys
→ Iterable<
K> -
The keys of this Map.
no setteroverride
- length → int
-
The number of key/value pairs in the map.
no setteroverride
-
onChange
→ Stream<
MapChange< K, V> > -
A stream of map changes.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ Iterable<
V> -
The values of this Map.
no setterinherited
Methods
-
addAll(
Map< K, V> other) → void -
Adds all key/value pairs of
otherto this map.inherited -
addChangeListener(
void listener(MapChange< K, V> )) → void - Registers a listener for map changes.
-
addEntries(
Iterable< MapEntry< newEntries) → voidK, V> > -
Adds all key/value pairs of
newEntriesto this map.inherited -
cast<
RK, RV> () → Map< RK, RV> -
Provides a view of this map as having
RKkeys andRVinstances, if necessary.inherited -
clear(
) → void -
Removes all entries from the map.
override
-
containsKey(
Object? key) → bool -
Whether this map contains the given
key.inherited -
containsValue(
Object? value) → bool -
Whether this map contains the given
value.inherited -
dispose(
) → void - Disposes the observable map.
-
forEach(
void action(K key, V value)) → void -
Applies
actionto each key/value pair of the map.inherited -
map<
K2, V2> (MapEntry< K2, V2> transform(K key, V value)) → Map<K2, V2> -
Returns a new map where all entries of this map are transformed by
the given
convertfunction.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putIfAbsent(
K key, V ifAbsent()) → V -
Look up the value of
key, or add a new entry if it isn't there.inherited -
remove(
Object? key) → V? -
Removes
keyand its associated value, if present, from the map.override -
removeChangeListener(
void listener(MapChange< K, V> )) → void - Removes a previously registered change listener.
-
removeWhere(
bool test(K key, V value)) → void -
Removes all entries of this map that satisfy the given
test.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
update(
K key, V update(V value), {V ifAbsent()?}) → V -
Updates the value for the provided
key.inherited -
updateAll(
V update(K key, V value)) → void -
Updates all values.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object? key) → V? -
The value for the given
key, ornullifkeyis not in the map.override -
operator []=(
K key, V value) → void -
Associates the
keywith the givenvalue.override