PoolStats class

Stats about the connection pool.

Constructors

PoolStats({required int activeCount, required int idleCount, required int totalCreated, required int totalEvicted, required int totalWaited, required int totalTimeouts})
Creates a PoolStats.
const

Properties

activeCount int
The number of currently active (in-use) connections.
final
hashCode int
The hash code for this object.
no setterinherited
idleCount int
The number of idle (available) connections.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
Total number of connections (active + idle).
no setter
totalCreated int
Total number of connections ever created.
final
totalEvicted int
Total number of connections ever evicted.
final
totalTimeouts int
Total number of acquire timeouts.
final
totalWaited int
Total number of times acquire had to wait.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited