QueryPlan class

An optimized query execution plan.

Constructors

QueryPlan({required QueryAnalysis query, required CostEstimate cost, required List<IndexHint> suggestedIndexes, required List<FilterDesc> optimizedFilters, required List<QueryRewrite> appliedRewrites, required bool indexSortPossible, required int estimatedTimeUs})
Creates a QueryPlan.
const

Properties

appliedRewrites List<QueryRewrite>
Rewrite rules that were applied.
final
cost CostEstimate
The estimated cost.
final
estimatedTimeUs int
The estimated execution time in microseconds.
final
hashCode int
The hash code for this object.
no setterinherited
indexSortPossible bool
Whether an index can be used for sorting.
final
optimizedFilters List<FilterDesc>
The optimized filter order (most selective first).
final
query QueryAnalysis
The original query analysis.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestedIndexes List<IndexHint>
Indexes suggested for this query.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited