RangePartitionStrategy class

Range-based partitioning strategy.

Distributes keys based on value ranges. Keys are assigned to partitions based on defined range boundaries.

Inheritance

Constructors

RangePartitionStrategy(List boundaries)
Creates a RangePartitionStrategy with the given boundaries.

Properties

boundaries List
The range boundaries that define the partitions. If boundaries are a, b, c, partitions are:
final
hashCode int
The hash code for this object.
no setterinherited
partitionCount int
The number of partitions.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PartitionStrategyType
The type of this partition strategy.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
partitionFor(dynamic key) int
Determines the partition index for the given key.
override
partitionsForQuery(bool predicate(dynamic key)?) List<int>
Determines the partitions that might contain keys matching the given predicate. For full scans, returns all partitions.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited