SyncCursor class

A cursor that tracks the position in the sync stream.

Constructors

SyncCursor(DateTime lastSync, String? token)
Create a sync cursor.

Properties

hashCode int
The hash code for this object.
no setterinherited
lastSync DateTime
The timestamp of the last successful sync.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
An optional token for cursor-based pagination.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) SyncCursor