ttlBoxName top-level constant
String
const ttlBoxName
The name of the special internal box used to store TTL metadata.
Implementation
const String ttlBoxName = '__rift_ttl__';
The name of the special internal box used to store TTL metadata.
const String ttlBoxName = '__rift_ttl__';