AggregationOp class
An aggregation operation to perform during grouping.
Constructors
- AggregationOp(String outputField, AggregationOpType type, {String? inputField})
- Create an aggregation operation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputField → String?
-
The input field to aggregate (defaults to outputField if null).
final
- outputField → String
-
The name of the output field for the result.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AggregationOpType
-
The type of aggregation operation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited