BinaryMetadata class
Metadata for a stored binary entry.
Constructors
Properties
- hash → String
-
SHA-256 hash of the original (unencrypted) data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEncrypted → bool
-
Whether the binary data is encrypted.
final
- key → String
-
The key under which the binary is stored.
final
-
metadata
→ Map<
String, String> -
Additional user-provided metadata.
final
- mimeType → String?
-
The MIME type of the binary data (e.g., 'image/png').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
The original size of the binary data in bytes.
final
- storedAt → DateTime
-
When the binary was stored.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → BinaryMetadata - Deserialize from JSON.