FilterDesc class
Description of a filter in a query analysis.
Constructors
- FilterDesc(String field, String operator, dynamic value, {double? selectivity})
-
Creates a FilterDesc.
const
Properties
- estimatedSelectivity → double
-
Estimated selectivity, defaulting to a heuristic.
no setter
- field → String
-
The field name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isIndexFriendly → bool
-
Whether this filter can use an index on field.
no setter
- operator → String
-
The operator as a string (e.g., '>', '==', '<', '>=', '<=', '!=', 'in', 'contains').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectivity → double?
-
Estimated selectivity (0.0 to 1.0) — fraction of rows that pass this filter.
final
- value → dynamic
-
The filter value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited