FormState enum
Form state representing the overall state of a RiftForm.
Values
- pristine → const FormState
-
The form has not been modified.
- dirty → const FormState
-
The form has been modified but not saved.
- saving → const FormState
-
The form is currently being saved.
- saved → const FormState
-
The form has been saved successfully.
- invalid → const FormState
-
The form has validation errors.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited