IncrementalExporter class
Incremental export support for Rift. Exports only changes since the last export for efficient sync/backup.
Constructors
Properties
- currentVersion → int
-
The current version number.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastExportVersion → int
-
The version of the last export.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
export(
Box box) → Future< IncrementalExport> - Export changes since the last export.
-
import(
Box box, IncrementalExport data) → Future< void> - Import an incremental export into a box.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordDelete(
String key) → void - Record that a key was deleted at the current version.
-
recordPut(
String key) → void - Record that a key was put/updated at the current version.
-
reset(
) → void - Reset the exporter state.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited