QueryRewrite class
A rewrite rule applied to a query.
Constructors
- QueryRewrite({required QueryRewriteType type, required String description, required QueryAnalysis rewrittenQuery})
-
Creates a QueryRewrite.
const
Properties
- description → String
-
Description of the rewrite.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rewrittenQuery → QueryAnalysis
-
The rewritten query analysis.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → QueryRewriteType
-
The type of rewrite.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited