ReplicationConflict class
Represents a replication conflict between two versions.
Constructors
- ReplicationConflict({required String key, dynamic localValue, dynamic remoteValue, required DateTime localTimestamp, required DateTime remoteTimestamp, required String sourceNodeId})
-
Creates a ReplicationConflict.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
The key that has conflicting versions.
final
- localTimestamp → DateTime
-
The local version timestamp.
final
- localValue → dynamic
-
The local value.
final
- remoteTimestamp → DateTime
-
The remote version timestamp.
final
- remoteValue → dynamic
-
The remote value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceNodeId → String
-
The source node ID.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited