ReplicationEvent class
A replication event.
Constructors
- ReplicationEvent({required ReplicationEventType type, required String sourceNodeId, String? key, dynamic value, required DateTime timestamp})
-
Creates a ReplicationEvent.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String?
-
The key affected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceNodeId → String
-
The source node ID.
final
- timestamp → DateTime
-
When this event occurred.
final
- type → ReplicationEventType
-
The type of event.
final
- value → dynamic
-
The value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited