SnapshotChange class
A change between two snapshots.
Constructors
- SnapshotChange({required dynamic key, dynamic oldValue, dynamic newValue, required SnapshotChangeType type})
-
Creates a SnapshotChange.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → dynamic
-
The key that changed.
final
- newValue → dynamic
-
The new value (null if the key was deleted).
final
- oldValue → dynamic
-
The old value (null if the key was added).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → SnapshotChangeType
-
The type of change.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited