SortCondition class
A sort condition for a query.
Specifies a field to sort by and a SortOrder direction.
Properties
-
field
→ String
-
The name of the field to sort by.
final
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
order
→ SortOrder
-
The sort direction.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compare(dynamic a, dynamic b)
→ int
-
Compare two values using this sort condition.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override