TimeTravelEvent class
A single recorded event in the time travel log.
Constructors
- TimeTravelEvent({required int version, required DateTime timestamp, required TimeTravelEventType type, String? key, dynamic oldValue, dynamic newValue})
- Create a time travel event.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String?
-
The key that was affected (null for clear events).
final
- newValue → dynamic
-
The value after the change.
final
- oldValue → dynamic
-
The value before the change.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
When this event occurred.
final
- type → TimeTravelEventType
-
The type of event.
final
- version → int
-
The version number (monotonically increasing).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited