ValidationResult class
Result of validating data against a schema.
Constructors
-
ValidationResult(List<
ValidationError> errors) -
Creates a ValidationResult.
const
Properties
-
errors
→ List<
ValidationError> -
The field-level errors found during validation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInvalid → bool
-
Whether the data is invalid (has errors).
no setter
- isValid → bool
-
Whether the data is valid (no errors).
no setter
-
messages
→ List<
String> -
Gets all error messages as a list.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
errorsFor(
String field) → List< ValidationError> -
Gets errors for a specific
field. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited