ValidationSchema class
Schema definition for a box.
Maps box names to their validation rules.
Constructors
-
ValidationSchema({required String boxName, required List<
ValidationRule> rules, bool allowExtraFields = true}) -
const
Properties
- allowExtraFields → bool
-
Whether to allow extra fields not defined in the schema.
final
- boxName → String
-
The name of the box this schema applies to.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rules
→ List<
ValidationRule> -
Validation rules for fields in this box.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited