VersionDiff class
Represents the diff between two entry versions.
Constructors
Properties
-
addedFields
→ Map<
String, dynamic> -
Fields that were added (not present in from, present in to).
final
- fromVersion → int
-
The source version.
final
- hasChanges → bool
-
Whether there are any differences between the versions.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modifiedFieldsNew
→ Map<
String, dynamic> -
Fields that were modified (present in both, different values).
final
-
modifiedFieldsOld
→ Map<
String, dynamic> -
Fields that were modified (present in both, different values).
final
-
removedFields
→ Map<
String, dynamic> -
Fields that were removed (present in from, not present in to).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toVersion → int
-
The target version.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited